from __future__ import annotations

import sys

from termcolor import colored

from jvnpack.harmonic_mean import harmonic_mean


def main():
    nums = _parse_nums(sys.argv[1:])
    mean = _calculate_results(nums)
    output = _format_output(mean)
    print(output)


def _parse_nums(inputs: list[str]) -> list[float]:
    try:
        nums = [float(i.strip()) for i in inputs]
    except ValueError:
        nums = []
    return nums


def _calculate_results(nums: list[float]) -> float:
    try:
        mean = harmonic_mean(nums)
    except ZeroDivisionError:
        mean = 0.0
    return mean


def _format_output(result: float) -> str:
    formated_result = colored(str(result), "red", "on_cyan", attrs=["bold"])
    return formated_result



import sys
import pytest

from termcolor import colored

from jvnpack.harmony import main


def test_always_passes():
    assert True


@pytest.mark.parametrize(
    "inputs, expected_value",
    [
        (["1", "4", "4"], 2.0),
        (["1", "0"], 0.0),
        (["1", "a"], 0.0),
    ],
)
def test_harmony_happy_path(monkeypatch, capsys, inputs, expected_value):
    monkeypatch.setattr(sys, "argv", ["harmony"] + inputs)

    main()

    assert capsys.readouterr().out.strip() == colored(
        expected_value,
        "red",
        "on_cyan",
        attrs=["bold"],
    )


@pytest.mark.xfail
def test_something():
    raise AssertionError()
